==> validation-model-arlington-1.25.340-sources.jar: org/verapdf/gf/model/impl/pd/gfse/contents/GFSESimpleContentItem.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse.contents;

import org.verapdf.model.selayer.SESimpleContentItem;
import org.verapdf.tools.TaggedPDFConstants;

/**
 * @author Maxim Plushchov
 */
public abstract class GFSESimpleContentItem extends GFSEContentItem implements SESimpleContentItem {

    protected final GFSEGroupedContent groupedContent;

    public GFSESimpleContentItem(String objectType, GFSEGroupedContent groupedContent) {
        super(objectType);
        this.groupedContent = groupedContent;
    }

    @Override
    public abstract String getitemType();

    @Override
    public Boolean getisFigure() {
        return groupedContent.hasParentWithStandardType(TaggedPDFConstants.FIGURE);
    }

    @Override
    public Boolean getisFormula() {
        return groupedContent.hasParentWithStandardType(TaggedPDFConstants.FORMULA);
    }
    
    @Override
    public Boolean getisArtifact() {
        return groupedContent.getisArtifact();
    }

    @Override
    public String getparentsTags() {
        return groupedContent.getparentsTags();
    }

    @Override
    public String getparentStructureTag() {
        return groupedContent.getparentStructureTag();
    }

    @Override
    public String getparentStandardTag() {
        return groupedContent.getparentStandardTag();
    }

    @Override
    public Boolean getisSignature() {
        return groupedContent.getisSignature();
    }

    @Override
    public String getActualText() {
        return groupedContent.getInheritedActualText();
    }

    @Override
    public String getAlt() {
        return groupedContent.getInheritedAlt();
    }

    @Override
    public Boolean getisTaggedContent() {
        return groupedContent.getisTaggedContent();
    }

    @Override
    public String getparentStructureElementObjectKey() {
        return groupedContent.getparentStructureElementObjectKey();
    }

    @Override
    public String getExtraContext() {
        Long mcid = groupedContent.getMCID();
        return mcid != null ? "mcid:" + mcid : null;
    }
}

==> validation-model-arlington-1.29.171-sources.jar: org/verapdf/gf/model/impl/pd/gfse/contents/GFSESimpleContentItem.java <==
/**
 * This file is part of veraPDF Validation for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse.contents;

import org.verapdf.model.selayer.SESimpleContentItem;
import org.verapdf.tools.TaggedPDFConstants;

import java.util.List;

/**
 * @author Maxim Plushchov
 */
public abstract class GFSESimpleContentItem extends GFSEContentItem implements SESimpleContentItem {

    protected final GFSEGroupedContent groupedContent;

    public GFSESimpleContentItem(String objectType, GFSEGroupedContent groupedContent) {
        super(objectType);
        this.groupedContent = groupedContent;
    }

    @Override
    public abstract String getitemType();

    @Override
    public Boolean getisFigure() {
        return groupedContent.hasParentWithStandardType(TaggedPDFConstants.FIGURE);
    }

    @Override
    public Boolean getisFormula() {
        return groupedContent.hasParentWithStandardType(TaggedPDFConstants.FORMULA);
    }
    
    @Override
    public Boolean getisArtifact() {
        return groupedContent.getisArtifact();
    }

    @Override
    public List<String> getparentsTags() {
        return groupedContent.getparentsTags();
    }

    @Override
    public String getparentStructureTag() {
        return groupedContent.getparentStructureTag();
    }

    @Override
    public String getparentStandardTag() {
        return groupedContent.getparentStandardTag();
    }

    @Override
    public Boolean getisSignature() {
        return groupedContent.getisSignature();
    }

    @Override
    public String getActualText() {
        return groupedContent.getInheritedActualText();
    }

    @Override
    public String getAlt() {
        return groupedContent.getInheritedAlt();
    }

    @Override
    public Boolean getisTaggedContent() {
        return groupedContent.getisTaggedContent();
    }

    @Override
    public String getparentStructureElementObjectKey() {
        return groupedContent.getparentStructureElementObjectKey();
    }

    @Override
    public String getExtraContext() {
        Long mcid = groupedContent.getMCID();
        return mcid != null ? "mcid:" + mcid : null;
    }
}
